/* APBasicLevel.h
 *
 * Copyright 1996-2014 by Cenon GmbH
 * Author:   Georg Fleischmann
 *
 * Created:  1996-03-03
 * Modified: 2003-03-29
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the Cenon Public License as
 * published by Cenon GmbH. Among other things, the
 * License requires that the copyright notices and this notice
 * be preserved on all copies.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the Cenon Public License for more details.
 *
 * You should have received a copy of the Cenon Public License along
 * with this program; see the file LICENSE. If not, write to Cenon.
 *
 * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
 * eMail: info@cenon.de
 * http://www.cenon.info
 */

#ifndef CEN_H_APBASICLEVEL
#define CEN_H_APBASICLEVEL

#include <AppKit/AppKit.h>

@interface APBasicLevel:NSPanel <NSWindowDelegate>
{
    id	window;		// Astro Panel
}

- init;
- (void)setWindow:win;
- window;
- (NSString*)name;
- (void)update:sender;
- (BOOL)isActive;

/* delegate methods
 */
- (void)displayWillEnd;

@end

#endif	// CEN_H_APBASICLEVEL
